# easyros
ros的安装与开发工具

## 使用环境
Ubuntun 20.04.6 LTS
## 使用指令
```
pip install easyros
easyros
```

## 功能
自动安装ros(包换源)  
github链接转镜像  
自动创造工作空间  


## 其它
因为ROS的环境安装过于复杂，所以我直接调用了鱼香的安装脚本 `https://github.com/fishros/install`  

